#ifndef __SPW_H
#define __SPW_H

#include <owl\applicat.h>
#include <owl\owlpch.h>
#include <owl\edit.h>
#include <owl\combobox.h>
#include <owl\floatfra.h>
#include <owl\radiobut.h>
#include <dir.h>
#include <ddeml.h>

#include "confdlg.h"

//
// A Combo box is actually made up of three windows, an edit
// window, a list box window, and a parent window.  If we need to trap
// an event on the edit or list box window, normal OWL event handlers
// won't work.  These event handlers would trap events to the parent
// window.
//
// TComboEdit is hard wired to the control ID that MS uses for the edit
// window. This allows us to trap events, like CR.
//

const int COMBO_LIST_ID = 0x3e8;  // Window ID for list box component
const int COMBO_EDIT_ID = 0x3e9;  // Window ID for edit field component

const int EDITWIDTH  = 300;  // Width of the combo box
const int CMDBUFSIZE = 256;  // Max command size
const int COMBO_ID   = 1;


class TComboEdit : public TEdit
{
public:
	TComboEdit(TComboBox* parent, UINT textLen)
	:
		TEdit(parent, COMBO_EDIT_ID, textLen)
		{
			Combo = parent;
		}

private:
	// This is where we'll look for c/r and special keys
	void EvChar(UINT key, UINT repeatCount, UINT flags);

	void ExecuteCmd(const char *cmd);

    void copyToClipboard(const char *str);


	// We could also get Parent from TWindow and downcast it
	TComboBox* Combo;

	char EditBuf[CMDBUFSIZE];
	char CmdBuf[CMDBUFSIZE];

	DECLARE_RESPONSE_TABLE(TComboEdit);
};

class TLineEdit : public TComboBox
{
public:
	TLineEdit(TWindow* p,int w, int h);
	TComboEdit* Ed;
};

class TMakePassFrame : public TFloatingFrame
{
public:
	TMakePassFrame(TWindow* client, char* title);
    ~TMakePassFrame();

#ifdef  __USEDDE

    virtual BOOL MatchTopicAndService(HSZ, HSZ);
    virtual BOOL MatchTopicAndItem(HSZ, HSZ);
    virtual HDDEDATA WildConnect(HSZ, HSZ, WORD);
    virtual HDDEDATA DataRequested(WORD);
    virtual void UpdateData();
    HCONV   HConv;

#endif

private:
	void    SetupWindow();
	TLineEdit* Cmd;

	void	CmConfig();
	void	CmAbout();

#ifdef  __USEDDE

    HSZ     Service;
    HSZ     Topic;
    HSZ     Item;

    DWORD   InstId();
#endif

	DECLARE_RESPONSE_TABLE(TMakePassFrame);
};

//------------------------------------------------------------------------

class TWinPass : public TApplication
{
public:

	TWinPass();
    virtual ~TWinPass();

    TConfigData config;

    DWORD   InstId;
    static  TMakePassFrame* This;

    static char ProfileName[MAXPATH];

protected:

    static const char *ApplicationName;

    
	void InitMainWindow();

    void InitInstance();
    int TermInstance(int status);

#ifdef  __USEDDE

    static HDDEDATA FAR PASCAL _export CallBack(WORD, WORD, HCONV, HSZ, HSZ,
                                                HDDEDATA, DWORD, DWORD);

    TProcInstance CallBackProc;

#endif

};

#endif
